==> blanco.plugin.svnconf_0.0.3-src.zip: src/blanco/svnconf/valueobject/BlancoSvnConfStructure.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.svnconf.valueobject;

import java.util.Date;
import java.util.List;

/**
 * blancoSvnConf̂ȂŗpValueObjectłB
 */
public class BlancoSvnConfStructure {
    /**
     * tB[h [name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Subversion|WgIDBK{ځB
     */
    private String fName;

    /**
     * tB[h [description]
     *
     * ڂ̌^ [java.lang.String]<br>
     * B
     */
    private String fDescription;

    /**
     * tB[h [hostname]
     *
     * ڂ̌^ [java.lang.String]<br>
     * zXgB
     */
    private String fHostname;

    /**
     * tB[h [baseDirectory]
     *
     * ڂ̌^ [java.lang.String]<br>
     * fBNgB
     */
    private String fBaseDirectory;

    /**
     * tB[h [managerName]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ǗIDB
     */
    private String fManagerName;

    /**
     * tB[h [validityPeriodBegin]
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEJn
     */
    private Date fValidityPeriodBegin;

    /**
     * tB[h [validityPeriodEnd]
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEI
     */
    private Date fValidityPeriodEnd;

    /**
     * tB[h [type]
     *
     * ڂ̌^ [java.lang.String]<br>
     * `敪 (new, update, delete)
     */
    private String fType;

    /**
     * tB[h [anonymousAuth]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o^җp (none, r, rw)
     */
    private String fAnonymousAuth;

    /**
     * tB[h [userList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * tB[hێ郊XgB
     */
    private List fUserList = new java.util.ArrayList();

    /**
     * tB[h [name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Subversion|WgIDBK{ځB
     *
     * @param argName tB[h[name]Ɋi[l
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h[name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Subversion|WgIDBK{ځB
     *
     * @return tB[h[name]Ɋi[Ăl
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [description]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * B
     *
     * @param argDescription tB[h[description]Ɋi[l
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h[description]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * B
     *
     * @return tB[h[description]Ɋi[Ăl
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [hostname]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * zXgB
     *
     * @param argHostname tB[h[hostname]Ɋi[l
     */
    public void setHostname(final String argHostname) {
        fHostname = argHostname;
    }

    /**
     * tB[h[hostname]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * zXgB
     *
     * @return tB[h[hostname]Ɋi[Ăl
     */
    public String getHostname() {
        return fHostname;
    }

    /**
     * tB[h [baseDirectory]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * fBNgB
     *
     * @param argBaseDirectory tB[h[baseDirectory]Ɋi[l
     */
    public void setBaseDirectory(final String argBaseDirectory) {
        fBaseDirectory = argBaseDirectory;
    }

    /**
     * tB[h[baseDirectory]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * fBNgB
     *
     * @return tB[h[baseDirectory]Ɋi[Ăl
     */
    public String getBaseDirectory() {
        return fBaseDirectory;
    }

    /**
     * tB[h [managerName]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ǗIDB
     *
     * @param argManagerName tB[h[managerName]Ɋi[l
     */
    public void setManagerName(final String argManagerName) {
        fManagerName = argManagerName;
    }

    /**
     * tB[h[managerName]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ǗIDB
     *
     * @return tB[h[managerName]Ɋi[Ăl
     */
    public String getManagerName() {
        return fManagerName;
    }

    /**
     * tB[h [validityPeriodBegin]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEJn
     *
     * @param argValidityPeriodBegin tB[h[validityPeriodBegin]Ɋi[l
     */
    public void setValidityPeriodBegin(final Date argValidityPeriodBegin) {
        fValidityPeriodBegin = argValidityPeriodBegin;
    }

    /**
     * tB[h[validityPeriodBegin]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEJn
     *
     * @return tB[h[validityPeriodBegin]Ɋi[Ăl
     */
    public Date getValidityPeriodBegin() {
        return fValidityPeriodBegin;
    }

    /**
     * tB[h [validityPeriodEnd]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEI
     *
     * @param argValidityPeriodEnd tB[h[validityPeriodEnd]Ɋi[l
     */
    public void setValidityPeriodEnd(final Date argValidityPeriodEnd) {
        fValidityPeriodEnd = argValidityPeriodEnd;
    }

    /**
     * tB[h[validityPeriodEnd]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEI
     *
     * @return tB[h[validityPeriodEnd]Ɋi[Ăl
     */
    public Date getValidityPeriodEnd() {
        return fValidityPeriodEnd;
    }

    /**
     * tB[h [type]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * `敪 (new, update, delete)
     *
     * @param argType tB[h[type]Ɋi[l
     */
    public void setType(final String argType) {
        fType = argType;
    }

    /**
     * tB[h[type]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * `敪 (new, update, delete)
     *
     * @return tB[h[type]Ɋi[Ăl
     */
    public String getType() {
        return fType;
    }

    /**
     * tB[h [anonymousAuth]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o^җp (none, r, rw)
     *
     * @param argAnonymousAuth tB[h[anonymousAuth]Ɋi[l
     */
    public void setAnonymousAuth(final String argAnonymousAuth) {
        fAnonymousAuth = argAnonymousAuth;
    }

    /**
     * tB[h[anonymousAuth]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o^җp (none, r, rw)
     *
     * @return tB[h[anonymousAuth]Ɋi[Ăl
     */
    public String getAnonymousAuth() {
        return fAnonymousAuth;
    }

    /**
     * tB[h [userList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * tB[hێ郊XgB
     *
     * @param argUserList tB[h[userList]Ɋi[l
     */
    public void setUserList(final List argUserList) {
        fUserList = argUserList;
    }

    /**
     * tB[h[userList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * tB[hێ郊XgB
     *
     * @return tB[h[userList]Ɋi[Ăl
     */
    public List getUserList() {
        return fUserList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.svnconf.valueobject.BlancoSvnConfStructure[");
        buf.append("name=" + fName);
        buf.append(",description=" + fDescription);
        buf.append(",hostname=" + fHostname);
        buf.append(",baseDirectory=" + fBaseDirectory);
        buf.append(",managerName=" + fManagerName);
        buf.append(",validityPeriodBegin=" + fValidityPeriodBegin);
        buf.append(",validityPeriodEnd=" + fValidityPeriodEnd);
        buf.append(",type=" + fType);
        buf.append(",anonymousAuth=" + fAnonymousAuth);
        buf.append(",userList=" + fUserList);
        buf.append("]");
        return buf.toString();
    }
}

==> blanco.plugin.svnconf_0.0.9-src.zip: src/blanco/svnconf/valueobject/BlancoSvnConfStructure.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.svnconf.valueobject;

import java.util.Date;
import java.util.List;

/**
 * blancoSvnConf̂ȂŗpValueObjectłB
 */
public class BlancoSvnConfStructure {
    /**
     * tB[h [name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * Subversion|WgIDBK{ځB
     */
    private String fName;

    /**
     * tB[h [description]
     *
     * ڂ̌^ [java.lang.String]<br>
     * B
     */
    private String fDescription;

    /**
     * tB[h [hostname]
     *
     * ڂ̌^ [java.lang.String]<br>
     * zXgB
     */
    private String fHostname;

    /**
     * tB[h [baseDirectory]
     *
     * ڂ̌^ [java.lang.String]<br>
     * fBNgB
     */
    private String fBaseDirectory;

    /**
     * tB[h [administratorName]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ǗIDB
     */
    private String fAdministratorName;

    /**
     * tB[h [validityPeriodBegin]
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEJn
     */
    private Date fValidityPeriodBegin;

    /**
     * tB[h [validityPeriodEnd]
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEI
     */
    private Date fValidityPeriodEnd;

    /**
     * tB[h [type]
     *
     * ڂ̌^ [java.lang.String]<br>
     * `敪 (new, update, delete)
     */
    private String fType;

    /**
     * tB[h [anonymousAuth]
     *
     * ڂ̌^ [java.lang.String]<br>
     * o^җp (none, r, rw)
     */
    private String fAnonymousAuth;

    /**
     * tB[h [userList]
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * tB[hێ郊XgB
     */
    private List fUserList = new java.util.ArrayList();

    /**
     * tB[h [name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Subversion|WgIDBK{ځB
     *
     * @param argName tB[h[name]Ɋi[l
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h[name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * Subversion|WgIDBK{ځB
     *
     * @return tB[h[name]Ɋi[Ăl
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [description]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * B
     *
     * @param argDescription tB[h[description]Ɋi[l
     */
    public void setDescription(final String argDescription) {
        fDescription = argDescription;
    }

    /**
     * tB[h[description]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * B
     *
     * @return tB[h[description]Ɋi[Ăl
     */
    public String getDescription() {
        return fDescription;
    }

    /**
     * tB[h [hostname]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * zXgB
     *
     * @param argHostname tB[h[hostname]Ɋi[l
     */
    public void setHostname(final String argHostname) {
        fHostname = argHostname;
    }

    /**
     * tB[h[hostname]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * zXgB
     *
     * @return tB[h[hostname]Ɋi[Ăl
     */
    public String getHostname() {
        return fHostname;
    }

    /**
     * tB[h [baseDirectory]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * fBNgB
     *
     * @param argBaseDirectory tB[h[baseDirectory]Ɋi[l
     */
    public void setBaseDirectory(final String argBaseDirectory) {
        fBaseDirectory = argBaseDirectory;
    }

    /**
     * tB[h[baseDirectory]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * fBNgB
     *
     * @return tB[h[baseDirectory]Ɋi[Ăl
     */
    public String getBaseDirectory() {
        return fBaseDirectory;
    }

    /**
     * tB[h [administratorName]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ǗIDB
     *
     * @param argAdministratorName tB[h[administratorName]Ɋi[l
     */
    public void setAdministratorName(final String argAdministratorName) {
        fAdministratorName = argAdministratorName;
    }

    /**
     * tB[h[administratorName]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ǗIDB
     *
     * @return tB[h[administratorName]Ɋi[Ăl
     */
    public String getAdministratorName() {
        return fAdministratorName;
    }

    /**
     * tB[h [validityPeriodBegin]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEJn
     *
     * @param argValidityPeriodBegin tB[h[validityPeriodBegin]Ɋi[l
     */
    public void setValidityPeriodBegin(final Date argValidityPeriodBegin) {
        fValidityPeriodBegin = argValidityPeriodBegin;
    }

    /**
     * tB[h[validityPeriodBegin]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEJn
     *
     * @return tB[h[validityPeriodBegin]Ɋi[Ăl
     */
    public Date getValidityPeriodBegin() {
        return fValidityPeriodBegin;
    }

    /**
     * tB[h [validityPeriodEnd]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEI
     *
     * @param argValidityPeriodEnd tB[h[validityPeriodEnd]Ɋi[l
     */
    public void setValidityPeriodEnd(final Date argValidityPeriodEnd) {
        fValidityPeriodEnd = argValidityPeriodEnd;
    }

    /**
     * tB[h[validityPeriodEnd]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.Date]<br>
     * LԁEI
     *
     * @return tB[h[validityPeriodEnd]Ɋi[Ăl
     */
    public Date getValidityPeriodEnd() {
        return fValidityPeriodEnd;
    }

    /**
     * tB[h [type]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * `敪 (new, update, delete)
     *
     * @param argType tB[h[type]Ɋi[l
     */
    public void setType(final String argType) {
        fType = argType;
    }

    /**
     * tB[h[type]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * `敪 (new, update, delete)
     *
     * @return tB[h[type]Ɋi[Ăl
     */
    public String getType() {
        return fType;
    }

    /**
     * tB[h [anonymousAuth]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o^җp (none, r, rw)
     *
     * @param argAnonymousAuth tB[h[anonymousAuth]Ɋi[l
     */
    public void setAnonymousAuth(final String argAnonymousAuth) {
        fAnonymousAuth = argAnonymousAuth;
    }

    /**
     * tB[h[anonymousAuth]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * o^җp (none, r, rw)
     *
     * @return tB[h[anonymousAuth]Ɋi[Ăl
     */
    public String getAnonymousAuth() {
        return fAnonymousAuth;
    }

    /**
     * tB[h [userList]̃Zb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * tB[hێ郊XgB
     *
     * @param argUserList tB[h[userList]Ɋi[l
     */
    public void setUserList(final List argUserList) {
        fUserList = argUserList;
    }

    /**
     * tB[h[userList]̃Qb^[\bh
     *
     * ڂ̌^ [java.util.List]<br>
     * Kl   [new java.util.ArrayList()]<br>
     * tB[hێ郊XgB
     *
     * @return tB[h[userList]Ɋi[Ăl
     */
    public List getUserList() {
        return fUserList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.svnconf.valueobject.BlancoSvnConfStructure[");
        buf.append("name=" + fName);
        buf.append(",description=" + fDescription);
        buf.append(",hostname=" + fHostname);
        buf.append(",baseDirectory=" + fBaseDirectory);
        buf.append(",administratorName=" + fAdministratorName);
        buf.append(",validityPeriodBegin=" + fValidityPeriodBegin);
        buf.append(",validityPeriodEnd=" + fValidityPeriodEnd);
        buf.append(",type=" + fType);
        buf.append(",anonymousAuth=" + fAnonymousAuth);
        buf.append(",userList=" + fUserList);
        buf.append("]");
        return buf.toString();
    }
}
